from dna_mutation_quantifier.core import *
from dna_mutation_quantifier.calibration import RatioToEditingConverter, conversion_matrix
from dna_mutation_quantifier.sanger import NormalizedTrace
from dna_mutation_quantifier.analysis import ExperimentAnalysis, GrnaWithTargetSetup, QuantificationExperimentSetup


def fix_path(path: str):
  return path.replace("\\","/").replace('"', '')

def init_experiment(control_files,  target_files, grna_sequence, target_sequence, off_sites):
    controls = [NormalizedTrace.from_abi_file(fix_path(x)) for x in control_files]
    targets = [NormalizedTrace.from_abi_file(fix_path(x)) for x in target_files]

    grna_setup = GrnaWithTargetSetup(grna_sequence, target_sequence, list(off_sites.values()))
    conv = RatioToEditingConverter(conversion_matrix)
    experiment = QuantificationExperimentSetup(grna_setup, controls, targets, conv)

    anal = ExperimentAnalysis(experiment)

    return anal


def default_process_experiment(anal: ExperimentAnalysis):  
    log("Processing...")
    anal.process()
    log("Generating plots...")
    anal.generate_raw_plots()
    log("Exporting quant...")
    anal.export_quantification()